=================
TopoVelo
=================

TopoVelo stands for Topological velocity inference. It is a tool for joint modeling temporal gene expression and spatial cellular dynamics from spatial transcriptomic data.
The main method applies the graph variational autoencoder to recover spatially-coupled RNA velocity and reveal the spatial migration of cells during tissue growth.

## Installation
```bash
pip install topovelo